AVAILABLE_DIMENSIONS = [
    "AZ",
    "INSTANCE_TYPE",
    "LINKED_ACCOUNT",
    "OPERATION",
    "PURCHASE_TYPE",
    "SERVICE",
    "USAGE_TYPE",
    "PLATFORM",
    "TENANCY",
    "RECORD_TYPE",
    "LEGAL_ENTITY_NAME",
    "DEPLOYMENT_OPTION",
    "DATABASE_ENGINE",
    "CACHE_ENGINE",
    "INSTANCE_TYPE_FAMILY",
    "REGION",
    "BILLING_ENTITY",
    "RESERVATION_ID",
    "SAVINGS_PLANS_TYPE",
    "SAVINGS_PLAN_ARN",
    "OPERATING_SYSTEM",
]

AVAILABLE_METRICS = [
    "BlendedCost",
    "UnblendedCost",
    "AmortizedCost",
    "NetAmortizedCost",
    "NetUnblendedCost",
    "UsageQuantity",
    "NormalizedUsageAmount",
]

DEFAULT_METRICS = "UnblendedCost"
DEFAULT_POINT = 7
